library(testthat)
library(portalr)

test_check("portalr")
